@@ -47,7 +47,7 @@ impl Api {
     }
 
     pub(crate) async fn is_unauthorized(&self) -> bool {
-        self.get_all_clusters()
+        self.head("/clusters")
             .await
             .err()
             .and_then(|e| e.downcast::<reqwest::Error>().ok())
@@ -303,6 +303,23 @@ impl Api {
             .inspect(|output| self.inspect(output))
     }
 
+    async fn head<P>(&self, path: P) -> ApiResult<()>
+    where
+        P: fmt::Display,
+    {
+        let url = self.url(path);
+        self.client()?
+            .head(url)
+            .optionally_bearer_auth(self.token.as_ref())
+            .inspect()
+            .retry()
+            .await?
+            .error_for_status2()
+            .await?
+            .try_into()
+            .inspect(|output| self.inspect(output))
+    }
+
     async fn post<P, B, T, U>(&self, path: P, body: B) -> ApiResult<U>
     where
         P: fmt::Display,
@@ -394,7 +411,11 @@ impl Inspector for reqwest::RequestBuilder {
             log::trace!("{} {}", request.method(), request.url());
 
             request.headers().iter().for_each(|(header, value)| {
-                log::trace!("{}: {}", header, String::from_utf8_lossy(value.as_bytes()))
+                if header == reqwest::header::AUTHORIZATION {
+                    log::trace!("{}: {}", header, "[REDACTED]");
+                } else {
+                    log::trace!("{}: {}", header, String::from_utf8_lossy(value.as_bytes()))
+                }
             });
         }
 
